Functions to coerce Clojure types to Undertow Java classes.
Functions to coerce Clojure types to Undertow Java classes.
(*handler-fn-adapter* handler-fn)The function (fn [f] handler) to coerce Clojure functions to HttpHandler
instances.
server/set-handler-fn-adapter function.The function `(fn [f] handler)` to coerce Clojure functions to `HttpHandler` instances. - Default implementation raise exception. - Can be overridden permanently using `server/set-handler-fn-adapter` function.
(as-handler obj)Coerces obj to the instance of HttpHandler.
Coerces `obj` to the instance of `HttpHandler`.
(as-option k v)Coerces option k to the pair of Undertow option and value of correct type.
Used to create keyword aliases to Java objects of Undertow objects.
Coerces option `k` to the pair of Undertow option and value of correct type. Used to create keyword aliases to Java objects of Undertow objects.
(as-option-map m)Coerces Clojure map to Undertow's OptionMap.
Coerces Clojure map to Undertow's `OptionMap`.
(as-resource-manager obj)Coerces obj to the instance of
io.undertow.server.handlers.resource.ResourceManager
Coerces `obj` to the instance of `io.undertow.server.handlers.resource.ResourceManager`
(as-session-config obj)Coerces obj to the instance of SessionConfig.
Coerces `obj` to the instance of `SessionConfig`.
(as-session-manager obj)Coerces obj to the instance of SessionManager.
Coerces `obj` to the instance of `SessionManager`.
(as-wrapper obj)Coerces obj to the 1-arity function which wraps handler and returns new
handler.
Coerces `obj` to the 1-arity function which wraps handler and returns new handler.
(as-listener-builder obj)Coerces obj to the instance of io.undertow.Undertow$ListenerBuilder.
Coerces `obj` to the instance of `io.undertow.Undertow$ListenerBuilder`.
(as-response-commit-listener obj)Coerces obj to the instance of ResponseCommitListener.
Coerces `obj` to the instance of `ResponseCommitListener`.
(as-websocket-callback obj)Coerces obj to the instance of WebSocketCallback.
Coerces `obj` to the instance of `WebSocketCallback`.
(as-websocket-listener obj)Coerces obj to the instance of ChannelListener.
Coerces `obj` to the instance of `ChannelListener`.
(as-websocket-connection-callback obj)Coerces obj to the instance of WebSocketConnectionCallback.
Coerces `obj` to the instance of `WebSocketConnectionCallback`.
(bean* obj)Takes a Java object and returns a read-only implementation of the map
abstraction based upon its JavaBean properties. Applied recursively if
necessary. Returns object itself if bean* is not assigned for the type.
Takes a Java object and returns a read-only implementation of the map abstraction based upon its JavaBean properties. Applied recursively if necessary. Returns object itself if `bean*` is not assigned for the type.
(deep-bean classes object)Takes a Java object and returns a read-only implementation of the map
abstraction based upon its JavaBean properties. Applied recursively and only
on instances of classes.
Takes a Java object and returns a read-only implementation of the map abstraction based upon its JavaBean properties. Applied recursively and only on instances of `classes`.
(object-type obj)Returns object type to be used as dispatch value for multimethods.
(type obj).:type key or IPersistentMap.(type obj).If type is not an instance of symbol/keyword/class then class of this instance
returned. If obj is Var it is deref’ed.
Returns object type to be used as dispatch value for multimethods. - for records returns `(type obj)`. - for maps returns value of the `:type` key or `IPersistentMap`. - for other objects returns `(type obj)`. If type is not an instance of symbol/keyword/class then class of this instance returned. If `obj` is `Var` it is deref’ed.
(server-start obj)Starts Undertow server given obj, returns closeable ServerInstance.
Starts Undertow server given `obj`, returns closeable ServerInstance.
(server-stop obj)Stops Undertow server, returns nil.
Stops Undertow server, returns nil.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |