Functions to coerce Clojure types to Undertow Java classes.
Functions to coerce Clojure types to Undertow Java classes.
The function (fn [f] handler) to coerce Clojure functions to HttpHandler
instances.
server/set-handler-fn-adapter function.The function `(fn [f] handler)` to coerce Clojure functions to `HttpHandler` instances. - Default implementation raise exception. - Can be overridden permanently using `server/set-handler-fn-adapter` function.
(as-handler obj)Coerces obj to the instance of HttpHandler.
Coerces `obj` to the instance of `HttpHandler`.
(as-listener-builder obj)Coerces obj to the instance of io.undertow.Undertow$ListenerBuilder.
Coerces `obj` to the instance of `io.undertow.Undertow$ListenerBuilder`.
(as-option k v)Coerces option k to the pair of Undertow option and value of correct type.
Used to create keyword aliases to Java objects of Undertow objects.
Coerces option `k` to the pair of Undertow option and value of correct type. Used to create keyword aliases to Java objects of Undertow objects.
(as-option-map m)Coerces Clojure map to Undertow's OptionMap.
Coerces Clojure map to Undertow's `OptionMap`.
(as-resource-manager obj)Coerces obj to the instance of
io.undertow.server.handlers.resource.ResourceManager
Coerces `obj` to the instance of `io.undertow.server.handlers.resource.ResourceManager`
(as-session-config obj)Coerces obj to the instance of SessionConfig.
Coerces `obj` to the instance of `SessionConfig`.
(as-session-manager obj)Coerces obj to the instance of SessionManager.
Coerces `obj` to the instance of `SessionManager`.
(as-websocket-callback obj)Coerces obj to the instance of WebSocketCallback.
Coerces `obj` to the instance of `WebSocketCallback`.
(as-websocket-connection-callback obj)Coerces obj to the instance of WebSocketConnectionCallback.
Coerces `obj` to the instance of `WebSocketConnectionCallback`.
(as-websocket-listener obj)Coerces obj to the instance of ChannelListener.
Coerces `obj` to the instance of `ChannelListener`.
(as-wrapper obj)Coerces obj to the 1-arity function which wraps handler and returns new
handler.
Coerces `obj` to the 1-arity function which wraps handler and returns new handler.
(object-type obj)Returns object type to be used as dispatch value for multimethods.
:type key or :default.(type obj).Returns object type to be used as dispatch value for multimethods. - for maps returns value of the `:type` key or `:default`. - for other objects returns `(type obj)`.
(server-start obj)Starts Undertow server given obj, returns instance which can be stopped.
Starts Undertow server given `obj`, returns instance which can be stopped.
(server-stop obj)Stops Undertow server, returns nil.
Stops Undertow server, returns nil.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |